@@ -972,7 +972,7 @@ def polarBarChart(
 def polarBarRanks(
         dfRank, ranksNum,
         cats=['kill', 'death', 'assist', 'paint'],
-        yRange=(0, 1),
+        yRange=(0, 1), ticksStep=10,
         colors=['#EC0B68', '#3D59DE', '#6BFF00', '#38377A']
     ):
     # Get Values --------------------------------------------------------------
@@ -998,7 +998,7 @@ def polarBarRanks(
     (fig, ax_k) = polarBarChart(
         range(1, ranksNum+1)[::-1], vals[cats[0]], figAx=(fig, ax_k),
         logScale=False, rRange=(0, 90), yRange=yRange, labels=True,
-        origin='W', direction=-1, colors=[colors[0]]*ranksNum
+        origin='W', direction=-1, colors=[colors[0]]*ranksNum, ticksStep=ticksStep
     )
     ax_k.set_thetamin(thetaRange[0]); ax_k.set_thetamax(thetaRange[1])
     ax_k.text(.25, .9, cats[0], fontsize=15, ha='right', transform=ax_k.transAxes)
@@ -1007,7 +1007,7 @@ def polarBarRanks(
     (fig, ax_d) = polarBarChart(
         range(1, ranksNum+1)[::-1], vals[cats[1]], figAx=(fig, ax_d),
         logScale=False, rRange=(0, 90), yRange=yRange, labels=True,
-        origin='N', direction=-1, colors=[colors[1]]*ranksNum
+        origin='N', direction=-1, colors=[colors[1]]*ranksNum, ticksStep=ticksStep
     )
     ax_d.set_thetamin(thetaRange[0]); ax_d.set_thetamax(thetaRange[1])
     ax_d.text(.75, .9, cats[1], fontsize=15, ha='left', transform=ax_d.transAxes)
@@ -1016,7 +1016,7 @@ def polarBarRanks(
     (fig, ax_a) = polarBarChart(
         range(1, ranksNum+1)[::-1], vals[cats[2]], figAx=(fig, ax_a),
         logScale=False, rRange=(0, 90), yRange=yRange, labels=True,
-        origin='S', direction=-1, colors=[colors[2]]*ranksNum
+        origin='S', direction=-1, colors=[colors[2]]*ranksNum, ticksStep=ticksStep
     )
     ax_a.set_thetamin(thetaRange[0]); ax_a.set_thetamax(thetaRange[1])
     ax_a.text(.25, .1, cats[3], fontsize=15, ha='right', transform=ax_a.transAxes)
@@ -1025,7 +1025,7 @@ def polarBarRanks(
     (fig, ax_p) = polarBarChart(
         range(1, ranksNum+1)[::-1], vals[cats[3]], figAx=(fig, ax_p),
         logScale=False, rRange=(0, 90), yRange=yRange, labels=True,
-        origin='E', direction=-1, colors=[colors[3]]*ranksNum
+        origin='E', direction=-1, colors=[colors[3]]*ranksNum, ticksStep=ticksStep
     )
     ax_p.set_thetamin(thetaRange[0]); ax_p.set_thetamax(thetaRange[1])
     ax_p.text(.75, .1, cats[2], fontsize=15, ha='left', transform=ax_p.transAxes)
