@@ -266,7 +266,7 @@ def gaussianSmooth(y, gridSize=500, sd=1):
     Returns:
         list of np arrays: Smoothed values over the provided X range.
     """
-    x = range(y.shape[0])
+    x = range(len(y))
     grid = np.linspace(min(x), max(x), num=gridSize)
     weights = np.transpose([sts.norm.pdf(grid, m, sd) for m in x])
     weights = weights / weights.sum(0)
@@ -327,4 +327,25 @@ def ammendStagesStatsByType(
         dfIn['match type'] = [cat]*dfIn.shape[0]
         dfAmmend.append(dfIn)
     dfOut = pd.concat(dfAmmend)
-    return dfOut
\ No newline at end of file
+    return dfOut
+
+
+def longestRun(myList, elem='W'):
+    """Returns the longest consecutive run of appearances of the same element.
+
+    Args:
+        myList (list): List of elements.
+        elem (str, optional): Element to check for run. Defaults to 'W'.
+
+    Returns:
+        int: Longest run.
+    """    
+    (size, max_size) = (0, 0)
+    for i in myList:
+        if i == elem:
+            size += 1
+            if size > max_size:
+                max_size = size
+        else:
+            size = 0
+    return max_size
\ No newline at end of file
